==> haskell-filtrable-0.1.6.0-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filtrable
version:              0.1.6.0
visibility:           public
id:                   filtrable-0.1.6.0-5M2SygJ7uiqJsn1PPYyo8K
key:                  filtrable-0.1.6.0-5M2SygJ7uiqJsn1PPYyo8K
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  dc31966b0c8e0d0acde44cd01ea8d5eb
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filtrable
hs-libraries:         HSfiltrable-0.1.6.0-5M2SygJ7uiqJsn1PPYyo8K
depends:              base-4.18.2.1 containers-0.6.7 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filtrable-0.1.6.0-283-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filtrable
version:              0.1.6.0
visibility:           public
id:                   filtrable-0.1.6.0-KwSa4R3leAlAR7DiP2N6uI
key:                  filtrable-0.1.6.0-KwSa4R3leAlAR7DiP2N6uI
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  d7024a3b778a6eb4ed58354d7026f99c
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filtrable
hs-libraries:         HSfiltrable-0.1.6.0-KwSa4R3leAlAR7DiP2N6uI
depends:              base-4.18.2.1 containers-0.6.7 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
